@@ -3,8 +3,10 @@ Test known_phrases
 """
 from techiaith.tts.testun.known_phrases import replace_phrase
 
+# ERAILL POSIB: S4C ("es pedwar ec")
+
 
 def test_replace_phrase():
-    expected = "mae golwg tri chwech ddim yn wefan"
-    result = replace_phrase("mae golwg360 yn wefan")
+    expected = "gwefan yw golwg tri chwech dim"
+    result = replace_phrase("gwefan yw golwg360")
     assert expected == result
